==> zio-aws-mediapackagev2_2.12-7.21.15.13-sources.jar: zio/aws/mediapackagev2/model/CreateHlsManifestConfiguration.scala <==
package zio.aws.mediapackagev2.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.mediapackagev2.model.primitives.{
  CreateHlsManifestConfigurationProgramDateTimeIntervalSecondsInteger,
  CreateHlsManifestConfigurationManifestWindowSecondsInteger,
  ManifestName
}
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class CreateHlsManifestConfiguration(
    manifestName: ManifestName,
    childManifestName: Optional[ManifestName] = Optional.Absent,
    scteHls: Optional[zio.aws.mediapackagev2.model.ScteHls] = Optional.Absent,
    manifestWindowSeconds: Optional[
      CreateHlsManifestConfigurationManifestWindowSecondsInteger
    ] = Optional.Absent,
    programDateTimeIntervalSeconds: Optional[
      CreateHlsManifestConfigurationProgramDateTimeIntervalSecondsInteger
    ] = Optional.Absent,
    filterConfiguration: Optional[
      zio.aws.mediapackagev2.model.FilterConfiguration
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediapackagev2.model.CreateHlsManifestConfiguration = {
    import CreateHlsManifestConfiguration.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediapackagev2.model.CreateHlsManifestConfiguration
      .builder()
      .manifestName(ManifestName.unwrap(manifestName): java.lang.String)
      .optionallyWith(
        childManifestName.map(value =>
          ManifestName.unwrap(value): java.lang.String
        )
      )(_.childManifestName)
      .optionallyWith(scteHls.map(value => value.buildAwsValue()))(_.scteHls)
      .optionallyWith(
        manifestWindowSeconds.map(value =>
          CreateHlsManifestConfigurationManifestWindowSecondsInteger.unwrap(
            value
          ): Integer
        )
      )(_.manifestWindowSeconds)
      .optionallyWith(
        programDateTimeIntervalSeconds.map(value =>
          CreateHlsManifestConfigurationProgramDateTimeIntervalSecondsInteger
            .unwrap(value): Integer
        )
      )(_.programDateTimeIntervalSeconds)
      .optionallyWith(filterConfiguration.map(value => value.buildAwsValue()))(
        _.filterConfiguration
      )
      .build()
  }
  def asReadOnly
      : zio.aws.mediapackagev2.model.CreateHlsManifestConfiguration.ReadOnly =
    zio.aws.mediapackagev2.model.CreateHlsManifestConfiguration
      .wrap(buildAwsValue())
}
object CreateHlsManifestConfiguration {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediapackagev2.model.CreateHlsManifestConfiguration
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.mediapackagev2.model.CreateHlsManifestConfiguration =
      zio.aws.mediapackagev2.model.CreateHlsManifestConfiguration(
        manifestName,
        childManifestName.map(value => value),
        scteHls.map(value => value.asEditable),
        manifestWindowSeconds.map(value => value),
        programDateTimeIntervalSeconds.map(value => value),
        filterConfiguration.map(value => value.asEditable)
      )
    def manifestName: ManifestName
    def childManifestName: Optional[ManifestName]
    def scteHls: Optional[zio.aws.mediapackagev2.model.ScteHls.ReadOnly]
    def manifestWindowSeconds
        : Optional[CreateHlsManifestConfigurationManifestWindowSecondsInteger]
    def programDateTimeIntervalSeconds: Optional[
      CreateHlsManifestConfigurationProgramDateTimeIntervalSecondsInteger
    ]
    def filterConfiguration
        : Optional[zio.aws.mediapackagev2.model.FilterConfiguration.ReadOnly]
    def getManifestName: ZIO[Any, Nothing, ManifestName] =
      ZIO.succeed(manifestName)
    def getChildManifestName: ZIO[Any, AwsError, ManifestName] =
      AwsError.unwrapOptionField("childManifestName", childManifestName)
    def getScteHls
        : ZIO[Any, AwsError, zio.aws.mediapackagev2.model.ScteHls.ReadOnly] =
      AwsError.unwrapOptionField("scteHls", scteHls)
    def getManifestWindowSeconds: ZIO[
      Any,
      AwsError,
      CreateHlsManifestConfigurationManifestWindowSecondsInteger
    ] =
      AwsError.unwrapOptionField("manifestWindowSeconds", manifestWindowSeconds)
    def getProgramDateTimeIntervalSeconds: ZIO[
      Any,
      AwsError,
      CreateHlsManifestConfigurationProgramDateTimeIntervalSecondsInteger
    ] = AwsError.unwrapOptionField(
      "programDateTimeIntervalSeconds",
      programDateTimeIntervalSeconds
    )
    def getFilterConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.mediapackagev2.model.FilterConfiguration.ReadOnly
    ] = AwsError.unwrapOptionField("filterConfiguration", filterConfiguration)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediapackagev2.model.CreateHlsManifestConfiguration
  ) extends zio.aws.mediapackagev2.model.CreateHlsManifestConfiguration.ReadOnly {
    override val manifestName: ManifestName =
      zio.aws.mediapackagev2.model.primitives.ManifestName(impl.manifestName())
    override val childManifestName: Optional[ManifestName] =
      zio.aws.core.internal
        .optionalFromNullable(impl.childManifestName())
        .map(value =>
          zio.aws.mediapackagev2.model.primitives.ManifestName(value)
        )
    override val scteHls
        : Optional[zio.aws.mediapackagev2.model.ScteHls.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.scteHls())
        .map(value => zio.aws.mediapackagev2.model.ScteHls.wrap(value))
    override val manifestWindowSeconds
        : Optional[CreateHlsManifestConfigurationManifestWindowSecondsInteger] =
      zio.aws.core.internal
        .optionalFromNullable(impl.manifestWindowSeconds())
        .map(value =>
          zio.aws.mediapackagev2.model.primitives
            .CreateHlsManifestConfigurationManifestWindowSecondsInteger(value)
        )
    override val programDateTimeIntervalSeconds: Optional[
      CreateHlsManifestConfigurationProgramDateTimeIntervalSecondsInteger
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.programDateTimeIntervalSeconds())
      .map(value =>
        zio.aws.mediapackagev2.model.primitives
          .CreateHlsManifestConfigurationProgramDateTimeIntervalSecondsInteger(
            value
          )
      )
    override val filterConfiguration
        : Optional[zio.aws.mediapackagev2.model.FilterConfiguration.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.filterConfiguration())
        .map(value =>
          zio.aws.mediapackagev2.model.FilterConfiguration.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediapackagev2.model.CreateHlsManifestConfiguration
  ): zio.aws.mediapackagev2.model.CreateHlsManifestConfiguration.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-mediapackagev2_3-7.21.15.11-sources.jar: zio/aws/mediapackagev2/model/CreateHlsManifestConfiguration.scala <==
package zio.aws.mediapackagev2.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.mediapackagev2.model.primitives.{
  CreateHlsManifestConfigurationProgramDateTimeIntervalSecondsInteger,
  CreateHlsManifestConfigurationManifestWindowSecondsInteger,
  ManifestName
}
import java.lang.Integer
import scala.jdk.CollectionConverters.*
final case class CreateHlsManifestConfiguration(
    manifestName: ManifestName,
    childManifestName: Optional[ManifestName] = Optional.Absent,
    scteHls: Optional[zio.aws.mediapackagev2.model.ScteHls] = Optional.Absent,
    manifestWindowSeconds: Optional[
      CreateHlsManifestConfigurationManifestWindowSecondsInteger
    ] = Optional.Absent,
    programDateTimeIntervalSeconds: Optional[
      CreateHlsManifestConfigurationProgramDateTimeIntervalSecondsInteger
    ] = Optional.Absent,
    filterConfiguration: Optional[
      zio.aws.mediapackagev2.model.FilterConfiguration
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediapackagev2.model.CreateHlsManifestConfiguration = {
    import CreateHlsManifestConfiguration.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediapackagev2.model.CreateHlsManifestConfiguration
      .builder()
      .manifestName(ManifestName.unwrap(manifestName): java.lang.String)
      .optionallyWith(
        childManifestName.map(value =>
          ManifestName.unwrap(value): java.lang.String
        )
      )(_.childManifestName)
      .optionallyWith(scteHls.map(value => value.buildAwsValue()))(_.scteHls)
      .optionallyWith(
        manifestWindowSeconds.map(value =>
          CreateHlsManifestConfigurationManifestWindowSecondsInteger.unwrap(
            value
          ): Integer
        )
      )(_.manifestWindowSeconds)
      .optionallyWith(
        programDateTimeIntervalSeconds.map(value =>
          CreateHlsManifestConfigurationProgramDateTimeIntervalSecondsInteger
            .unwrap(value): Integer
        )
      )(_.programDateTimeIntervalSeconds)
      .optionallyWith(filterConfiguration.map(value => value.buildAwsValue()))(
        _.filterConfiguration
      )
      .build()
  }
  def asReadOnly
      : zio.aws.mediapackagev2.model.CreateHlsManifestConfiguration.ReadOnly =
    zio.aws.mediapackagev2.model.CreateHlsManifestConfiguration
      .wrap(buildAwsValue())
}
object CreateHlsManifestConfiguration {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediapackagev2.model.CreateHlsManifestConfiguration
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.mediapackagev2.model.CreateHlsManifestConfiguration =
      zio.aws.mediapackagev2.model.CreateHlsManifestConfiguration(
        manifestName,
        childManifestName.map(value => value),
        scteHls.map(value => value.asEditable),
        manifestWindowSeconds.map(value => value),
        programDateTimeIntervalSeconds.map(value => value),
        filterConfiguration.map(value => value.asEditable)
      )
    def manifestName: ManifestName
    def childManifestName: Optional[ManifestName]
    def scteHls: Optional[zio.aws.mediapackagev2.model.ScteHls.ReadOnly]
    def manifestWindowSeconds
        : Optional[CreateHlsManifestConfigurationManifestWindowSecondsInteger]
    def programDateTimeIntervalSeconds: Optional[
      CreateHlsManifestConfigurationProgramDateTimeIntervalSecondsInteger
    ]
    def filterConfiguration
        : Optional[zio.aws.mediapackagev2.model.FilterConfiguration.ReadOnly]
    def getManifestName: ZIO[Any, Nothing, ManifestName] =
      ZIO.succeed(manifestName)
    def getChildManifestName: ZIO[Any, AwsError, ManifestName] =
      AwsError.unwrapOptionField("childManifestName", childManifestName)
    def getScteHls
        : ZIO[Any, AwsError, zio.aws.mediapackagev2.model.ScteHls.ReadOnly] =
      AwsError.unwrapOptionField("scteHls", scteHls)
    def getManifestWindowSeconds: ZIO[
      Any,
      AwsError,
      CreateHlsManifestConfigurationManifestWindowSecondsInteger
    ] =
      AwsError.unwrapOptionField("manifestWindowSeconds", manifestWindowSeconds)
    def getProgramDateTimeIntervalSeconds: ZIO[
      Any,
      AwsError,
      CreateHlsManifestConfigurationProgramDateTimeIntervalSecondsInteger
    ] = AwsError.unwrapOptionField(
      "programDateTimeIntervalSeconds",
      programDateTimeIntervalSeconds
    )
    def getFilterConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.mediapackagev2.model.FilterConfiguration.ReadOnly
    ] = AwsError.unwrapOptionField("filterConfiguration", filterConfiguration)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediapackagev2.model.CreateHlsManifestConfiguration
  ) extends zio.aws.mediapackagev2.model.CreateHlsManifestConfiguration.ReadOnly {
    override val manifestName: ManifestName =
      zio.aws.mediapackagev2.model.primitives.ManifestName(impl.manifestName())
    override val childManifestName: Optional[ManifestName] =
      zio.aws.core.internal
        .optionalFromNullable(impl.childManifestName())
        .map(value =>
          zio.aws.mediapackagev2.model.primitives.ManifestName(value)
        )
    override val scteHls
        : Optional[zio.aws.mediapackagev2.model.ScteHls.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.scteHls())
        .map(value => zio.aws.mediapackagev2.model.ScteHls.wrap(value))
    override val manifestWindowSeconds
        : Optional[CreateHlsManifestConfigurationManifestWindowSecondsInteger] =
      zio.aws.core.internal
        .optionalFromNullable(impl.manifestWindowSeconds())
        .map(value =>
          zio.aws.mediapackagev2.model.primitives
            .CreateHlsManifestConfigurationManifestWindowSecondsInteger(value)
        )
    override val programDateTimeIntervalSeconds: Optional[
      CreateHlsManifestConfigurationProgramDateTimeIntervalSecondsInteger
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.programDateTimeIntervalSeconds())
      .map(value =>
        zio.aws.mediapackagev2.model.primitives
          .CreateHlsManifestConfigurationProgramDateTimeIntervalSecondsInteger(
            value
          )
      )
    override val filterConfiguration
        : Optional[zio.aws.mediapackagev2.model.FilterConfiguration.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.filterConfiguration())
        .map(value =>
          zio.aws.mediapackagev2.model.FilterConfiguration.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediapackagev2.model.CreateHlsManifestConfiguration
  ): zio.aws.mediapackagev2.model.CreateHlsManifestConfiguration.ReadOnly =
    new Wrapper(impl)
}
